#############################################################################
#
# File:   MakeTestBinaries.mk
# Author: Dave Hefner
# Date:   Nov. 15, 2012
#
# This file is used to build test binaries.
#
# Copyright (C) 2012 Hewlett-Packard Co.  All rights reserved.
#
#############################################################################
#include ../common.mk

export

make-directories:=$(shell mkdir -p obj bin)

TEST_ROOT_DIR:=$(abspath $(CURDIR))
TEST_ROOT_NAME:=$(notdir $(CURDIR))

.SECONDEXPANSION:
.SUFFIXES:

.PHONY: clean indent

TEST_SRC_DIR := $(TEST_ROOT_DIR)
TEST_BIN_DIR := $(BUILD_ROOT)/bin
TEST_OBJ_DIR := $(TEST_ROOT_DIR)/obj

ifeq "$(TEST_SOURCES)" ""
    OPTIONAL_SOURCES_FILE:=$(wildcard $(TEST_SRC_DIR)/makefile.list)
    ifneq "$(OPTIONAL_SOURCES_FILE)" ""
        -include $(OPTIONAL_SOURCES_FILE)
    else
        TEST_SOURCES := $(notdir $(wildcard $(TEST_SRC_DIR)/*.cpp))
    endif
endif

TEST_OBJECTS := $(TEST_SOURCES:.cpp=.o)
TEST_OBJECTS_PATH := $(addprefix $(TEST_OBJ_DIR)/,$(TEST_OBJECTS))

TEST_BINNAMES:=$(TEST_SOURCES:.cpp=)
TEST_BINARIES:=$(addprefix $(abspath $(TEST_BIN_DIR))/, $(TEST_BINNAMES))

ifneq "$(MAKECMDGOALS)" "clean"
    ifeq "$(MAKECMDGOALS)" "static"
        export LIBRARIES:=$(STATIC_LIBRARIES)
    else
        export LIBRARIES:=$(SHARED_LIBRARIES)
    endif
endif

all: $(testBinaries)
ifeq "$(MAKELEVEL)" "1"
	@echo ""
	@echo "********************************"
	@echo "* Making ${OS} Version         *"
	@echo "********************************"
	@echo ""
	@$(L1_CPPC) --version
	-@$(MAKE) -k --no-print-directory -C $(BUILD_ROOT)/mhlib
	-@$(MAKE) -k --no-print-directory -C $(BUILD_ROOT)/lib
	-@$(MAKE) -k --no-print-directory -C $(BUILD_ROOT)/genlib
	-@$(MAKE) -k --no-print-directory -C $(BUILD_ROOT)/platlib
	-@$(MAKE) -k --no-print-directory -C $(BUILD_ROOT)/dplib
	-@$(MAKE) -k --no-print-directory -C $(BUILD_ROOT)/RCIMService
endif
	-@$(MAKE) -k LIBS:='$(LIBS)' testBinaries

print-%:
	@echo '$*=$($*)'
	@echo '    origin = $(origin $*)'
	@echo '    flavor = $(flavor $*)'
	@echo '    value = $(value $*)'

testBinaries: $(TEST_BINARIES)
testObjects: $(TEST_OBJECTS_PATH)	

$(TEST_OBJECTS_PATH): $(TEST_OBJ_DIR)/%.o: $(TEST_SRC_DIR)/$$*.cpp
	${CXX} $(CXXFLAGS) $(CPPFLAGS) $(TARGET_ARCH) $(LDFLAGS_RPATH) $< -o $@

$(TEST_BINARIES): $(LIBS)

$(TEST_BINARIES): $(TEST_BIN_DIR)%: $(TEST_OBJ_DIR)$$*.o
	$(CXX) $(TARGET_ARCH) $(LDFLAGS_RPATH) $< ${LIBRARIES} -o $@

ifneq "$(MAKECMDGOALS)" "clean"
    -include $(TEST_OBJ_DIR)/*.d
endif

indent:
	../sbin/prettyCode.sh $(TEST_SOURCES)

clean:
	@rm -rf $(TEST_BINARIES)
	@rm -rf obj

